==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Solid/BuildingCircleArrowRight.md <==
# BuildingCircleArrowRight


```text
fontawesome-6/Solid/BuildingCircleArrowRight
```

```text
include('fontawesome-6/Solid/BuildingCircleArrowRight')
```



| Illustration | BuildingCircleArrowRight |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/BuildingCircleArrowRight.png) | ![illustration for BuildingCircleArrowRight](../../fontawesome-6/Solid/BuildingCircleArrowRight.Local.png) |




## BuildingCircleArrowRight

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element BuildingCircleArrowRight
include('fontawesome-6/Solid/BuildingCircleArrowRight')

' renders the element
BuildingCircleArrowRight('BuildingCircleArrowRight', 'Building Circle Arrow Right', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element BuildingCircleArrowRight
include('fontawesome-6/Solid/BuildingCircleArrowRight')

' renders the element
BuildingCircleArrowRight('BuildingCircleArrowRight', 'Building Circle Arrow Right', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/fontawesome-6/Solid/BuildingCircleArrowRight.md <==
# BuildingCircleArrowRight


```text
fontawesome-6/Solid/BuildingCircleArrowRight
```

```text
include('fontawesome-6/Solid/BuildingCircleArrowRight')
```



| Illustration | BuildingCircleArrowRight |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/BuildingCircleArrowRight.png) | ![illustration for BuildingCircleArrowRight](../../fontawesome-6/Solid/BuildingCircleArrowRight.Local.png) |




## BuildingCircleArrowRight

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element BuildingCircleArrowRight
include('fontawesome-6/Solid/BuildingCircleArrowRight')

' renders the element
BuildingCircleArrowRight('BuildingCircleArrowRight', 'Building Circle Arrow Right', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element BuildingCircleArrowRight
include('fontawesome-6/Solid/BuildingCircleArrowRight')

' renders the element
BuildingCircleArrowRight('BuildingCircleArrowRight', 'Building Circle Arrow Right', 'an optional tech label', 'an optional description')
@enduml
```
